@@ -105,6 +105,7 @@ is_model <- function(x) {
       "geeglm",
       "glht",
       "glimML",
+      "Glm",
       "glm",
       "glmaag",
       "glmbb",
@@ -128,6 +129,7 @@ is_model <- function(x) {
       "gls",
       "gmnl",
       "gmm",
+      "heavyLme",
       "HLfit",
       "htest",
       "hurdle",
@@ -166,6 +168,7 @@ is_model <- function(x) {
       "mediate",
       "merMod",
       "merModList",
+      "meta_bma",
       "meta_fixed",
       "meta_random",
       "meta_ordered",
@@ -178,6 +181,7 @@ is_model <- function(x) {
       "mjoint",
       "mle",
       "mle2",
+      "mlergm",
       "mlm",
       "mlogit",
       "multinom",
@@ -198,8 +202,10 @@ is_model <- function(x) {
       "poissonmfx",
       "poissonirr",
       "polr",
+      "pseudoglm",
       "psm",
       "probitmfx",
+      "rankFD",
       "rdrobust",
       "ridgelm",
       "rjags",
@@ -213,6 +219,8 @@ is_model <- function(x) {
       "robmixglm",
       "rq",
       "rqss",
+      "sarlm",
+      "scam",
       "sem",
       "slm",
       "speedlm",
@@ -225,6 +233,7 @@ is_model <- function(x) {
       "survreg",
       "survPresmooth",
       "svyglm",
+      "svy_vglm",
       "svyolr",
       "test_mediation",
       "tobit",
