@@ -73,6 +73,13 @@ n_obs.merModList <- function(x, ...) {
 
 
 
+#' @export
+n_obs.mediate <- function(x, ...) {
+  x$nobs
+}
+
+
+
 #' @export
 n_obs.bayesx <- function(x, ...) {
   length(x$response)
@@ -390,13 +397,16 @@ n_obs.blrm <- function(x, ...) {
 }
 
 
-
 #' @export
 n_obs.mlogit <- function(x, ...) {
   nrow(x$model)
 }
 
 
+#' @export
+n_obs.Glm <- n_obs.mlogit
+
+
 #' @export
 n_obs.maxLik <- n_obs.mlogit
 
