@@ -2,7 +2,6 @@ if (require("testthat") &&
   require("insight") &&
   require("censReg") &&
   require("AER")) {
-  context("insight, censReg")
 
   data("Affairs", package = "AER")
   m1 <-
@@ -11,7 +10,7 @@ if (require("testthat") &&
     )
 
   test_that("model_info", {
-    expect_true(model_info(m1)$is_linear)
+    expect_false(model_info(m1)$is_linear)
     expect_true(model_info(m1)$is_censored)
   })
 
@@ -94,7 +93,8 @@ if (require("testthat") &&
         conditional = as.formula(
           "affairs ~ age + yearsmarried + religiousness + occupation + rating"
         )
-      )
+      ),
+      ignore_attr = TRUE
     )
   })
 
