@@ -2,7 +2,6 @@ if (require("testthat") &&
   require("insight") &&
   require("ordinal") &&
   require("MASS")) {
-  context("insight, model_info")
 
   data(housing, package = "MASS")
   m1 <- clm2(Sat ~ Infl + Type + Cont, weights = Freq, data = housing)
@@ -10,6 +9,7 @@ if (require("testthat") &&
   test_that("model_info", {
     expect_true(model_info(m1)$is_ordinal)
     expect_false(model_info(m1)$is_multinomial)
+    expect_false(model_info(m1)$is_linear)
   })
 
   test_that("find_predictors", {
@@ -65,7 +65,8 @@ if (require("testthat") &&
     expect_length(find_formula(m1), 1)
     expect_equal(
       find_formula(m1),
-      list(conditional = as.formula("Sat ~ Infl + Type + Cont"))
+      list(conditional = as.formula("Sat ~ Infl + Type + Cont")),
+      ignore_attr = TRUE
     )
   })
 
